# Historical
[![Build Status](https://travis-ci.org/Netflix-Skunkworks/historical.svg?branch=master)](https://travis-ci.org/Netflix-Skunkworks/historical)
[![Coverage Status](https://coveralls.io/repos/github/Netflix-Skunkworks/historical/badge.svg?branch=master)](https://coveralls.io/github/Netflix-Skunkworks/historical?branch=master)
[![PyPI version](https://badge.fury.io/py/historical.svg)](https://badge.fury.io/py/historical)

## Historical is under heavy development and is not ready for production use.

Please review the documentation that is hosted here: [https://netflix-skunkworks.github.io/historical](https://netflix-skunkworks.github.io/historical).

[![Historical Logo](mkdocs/docs/img/historical.jpg)](https://netflix-skunkworks.github.io/historical)
